@@ -13,9 +13,11 @@ def _LS_GPU_basic(SMatrix, y, numIterations, isSavingEachIteration, withTumor):
         TN = T * N
         if y.shape != (T, N):
             raise ValueError(f"Expected y shape: ({T}, {N}), got {y.shape}")
+
         A_flat = torch.from_numpy(SMatrix).to(device=device, dtype=torch.float32).permute(0, 3, 1, 2).reshape(TN, ZX)
         y_flat = torch.from_numpy(y).to(device=device, dtype=torch.float32).reshape(TN)
         theta_flat = torch.zeros(ZX, dtype=torch.float32, device=device)
+
         saved_theta = []
         saved_indices = []
         if isSavingEachIteration:
@@ -23,33 +25,40 @@ def _LS_GPU_basic(SMatrix, y, numIterations, isSavingEachIteration, withTumor):
             saved_indices.append(0)
             step = max(1, (numIterations - 1) // 999)
             save_count = 1
+
         col_norms = torch.norm(A_flat, dim=0, keepdim=True)
         A_normalized = A_flat / (col_norms + 1e-8)
         y_normalized = y_flat / (torch.norm(y_flat) + 1e-8)
+
         description = f"AOT-BioMaps -- LS Reconstruction ---- {'WITH' if withTumor else 'WITHOUT'} TUMOR ---- GPU {torch.cuda.current_device()}"
+
         with torch.no_grad():
             for k in trange(numIterations, desc=description):
-                r = y_normalized - A_normalized @ theta_flat
-                p = r.clone()
+                r = y_normalized - A_normalized @ theta_flat  # r est de taille (TN,)
+                p = A_normalized.T @ r  # p doit être de taille (ZX,), donc on multiplie par A_normalized.T
                 rsold = torch.dot(r, r)
+
                 for _ in range(2):
-                    Ap = A_normalized @ p
-                    alpha = rsold / (torch.dot(p, Ap) + 1e-8)
+                    Ap = A_normalized @ p  # Ap est de taille (TN,)
+                    alpha = rsold / (torch.dot(p, A_normalized.T @ Ap) + 1e-8)  # Correction du produit scalaire
                     theta_flat += alpha * p
                     r -= alpha * Ap
                     rsnew = torch.dot(r, r)
                     if rsnew < 1e-8:
                         break
-                    p = r + (rsnew / rsold) * p
+                    p = A_normalized.T @ r + (rsnew / rsold) * p  # Mise à jour de p
                     rsold = rsnew
+
                 if isSavingEachIteration and (k % step == 0 or k == numIterations - 1):
                     saved_theta.append(theta_flat.reshape(Z, X).clone())
                     saved_indices.append(k + 1)
                     save_count += 1
                     if save_count >= 1000:
                         break
+
         del A_flat, y_flat, A_normalized, y_normalized
         torch.cuda.empty_cache()
+
         if isSavingEachIteration:
             return [theta.cpu().numpy() for theta in saved_theta], saved_indices
         else:
